==> mx-select-sound_24.3.tar.xz: BUILD/translations/mx-select-sound_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="48"/>
        <location filename="../mainwindow.cpp" line="79"/>
        <location filename="../mainwindow.cpp" line="135"/>
        <location filename="../mainwindow.cpp" line="155"/>
        <location filename="../mainwindow.cpp" line="163"/>
        <source>MX Select Sound</source>
        <translation type="unfinished">MX izbira zvoka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your current default sound card is:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trenutno je izbrana zvočna kartica:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>Display help </source>
        <translation type="unfinished">Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Help</source>
        <translation type="unfinished">Pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Alt+H</source>
        <translation type="unfinished">Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>About this application</source>
        <translation type="unfinished">O tem programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="106"/>
        <source>About...</source>
        <translation type="unfinished">O programu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>Alt+B</source>
        <translation type="unfinished">Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="145"/>
        <source>Quit application</source>
        <translation type="unfinished">Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Close</source>
        <translation type="unfinished">Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <source>Apply</source>
        <translation type="unfinished">Uveljavi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select another sound card if necessary:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;/p&gt;Če je potrebno izberite drugo zvočno kartico:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your computer has more than one sound card, you can use this application to select the one to be default. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Če ima vaš računalnik več kot eno zvočno kartico, lahko uporabite to aplikacijo, da določite, katera bo privzeta. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Test current sound card</source>
        <translation type="unfinished">Preizkus trenutne zvočne kartice</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="79"/>
        <source>No sound cards/devices were found.</source>
        <translation type="unfinished">Zvočnih kartic ali naprav ni bilo mogoče najti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="91"/>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>none</source>
        <translation type="unfinished">brez</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="134"/>
        <source>About MX Select Sound</source>
        <translation type="unfinished">O programu MX Izbira zvoka</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>Version: </source>
        <translation type="unfinished">Različica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <source>Program for selecting the default sound card in MX Linux</source>
        <translation type="unfinished">Program za določitev privzete zvočne kartice v MX Linuxu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="155"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="163"/>
        <source>Could not play test sound.</source>
        <translation type="unfinished">Preizkusnega zvoka ni bilo mogoče predvajati.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation type="unfinished">Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished">Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation type="unfinished">Prekini</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Zapri</translation>
    </message>
</context>
<context>
    <name>mxselectsound</name>
    <message>
        <source>MX Select Sound</source>
        <translation type="vanished">MX izbira zvoka</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your current default sound card is:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trenutno je izbrana zvočna kartica:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Display help </source>
        <translation type="vanished">Prikaži pomoč</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="vanished">Pomoč</translation>
    </message>
    <message>
        <source>Alt+H</source>
        <translation type="vanished">Alt+H</translation>
    </message>
    <message>
        <source>About this application</source>
        <translation type="vanished">O tem programu</translation>
    </message>
    <message>
        <source>About...</source>
        <translation type="vanished">O programu...</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="vanished">Alt+B</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="vanished">Zapri aplikacijo</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Zapri</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="vanished">Alt+N</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="vanished">Uveljavi</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select another sound card if necessary:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;/p&gt;Če je potrebno izberite drugo zvočno kartico:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your computer has more than one sound card, you can use this application to select the one to be default. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Če ima vaš računalnik več kot eno zvočno kartico, lahko uporabite to aplikacijo, da določite, katera bo privzeta. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Test current sound card</source>
        <translation type="vanished">Preizkus trenutne zvočne kartice</translation>
    </message>
    <message>
        <source>No sound cards/devices were found.</source>
        <translation type="vanished">Zvočnih kartic ali naprav ni bilo mogoče najti</translation>
    </message>
    <message>
        <source>none</source>
        <translation type="vanished">brez</translation>
    </message>
    <message>
        <source>About MX Select Sound</source>
        <translation type="vanished">O programu MX Izbira zvoka</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">Različica:</translation>
    </message>
    <message>
        <source>Program for selecting the default sound card in MX Linux</source>
        <translation type="vanished">Program za določitev privzete zvočne kartice v MX Linuxu</translation>
    </message>
    <message>
        <source>Copyright (c) MX Linux</source>
        <translation type="vanished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licenca</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Dnevnik sprememb</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Prekini</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Zapri</translation>
    </message>
    <message>
        <source>Could not play test sound.</source>
        <translation type="vanished">Preizkusnega zvoka ni bilo mogoče predvajati.</translation>
    </message>
</context>
</TS>

==> mx-select-sound_25.4.tar.xz: BUILD/translations/mx-select-sound_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="48"/>
        <location filename="../mainwindow.cpp" line="79"/>
        <location filename="../mainwindow.cpp" line="135"/>
        <location filename="../mainwindow.cpp" line="155"/>
        <location filename="../mainwindow.cpp" line="163"/>
        <source>MX Select Sound</source>
        <translation type="unfinished">MX izbira zvoka</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your current default sound card is:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trenutno je izbrana zvočna kartica:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>Display help </source>
        <translation type="unfinished">Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Help</source>
        <translation type="unfinished">Pomoč</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Alt+H</source>
        <translation type="unfinished">Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="103"/>
        <source>About this application</source>
        <translation type="unfinished">O tem programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="106"/>
        <source>About...</source>
        <translation type="unfinished">O programu...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <source>Alt+B</source>
        <translation type="unfinished">Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="145"/>
        <source>Quit application</source>
        <translation type="unfinished">Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="148"/>
        <source>Close</source>
        <translation type="unfinished">Zapri</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <source>Apply</source>
        <translation type="unfinished">Uveljavi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select another sound card if necessary:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;/p&gt;Če je potrebno izberite drugo zvočno kartico:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your computer has more than one sound card, you can use this application to select the one to be default. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Če ima vaš računalnik več kot eno zvočno kartico, lahko uporabite to aplikacijo, da določite, katera bo privzeta. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Test current sound card</source>
        <translation type="unfinished">Preizkus trenutne zvočne kartice</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="79"/>
        <source>No sound cards/devices were found.</source>
        <translation type="unfinished">Zvočnih kartic ali naprav ni bilo mogoče najti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="91"/>
        <location filename="../mainwindow.cpp" line="104"/>
        <source>none</source>
        <translation type="unfinished">brez</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="134"/>
        <source>About MX Select Sound</source>
        <translation type="unfinished">O programu MX Izbira zvoka</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="135"/>
        <source>Version: </source>
        <translation type="unfinished">Različica:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="136"/>
        <source>Program for selecting the default sound card in MX Linux</source>
        <translation type="unfinished">Program za določitev privzete zvočne kartice v MX Linuxu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="140"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="155"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="163"/>
        <source>Could not play test sound.</source>
        <translation type="unfinished">Preizkusnega zvoka ni bilo mogoče predvajati.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation type="unfinished">Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished">Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation type="unfinished">Prekliči</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Zapri</translation>
    </message>
</context>
<context>
    <name>mxselectsound</name>
    <message>
        <source>MX Select Sound</source>
        <translation type="vanished">MX izbira zvoka</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Your current default sound card is:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Trenutno je izbrana zvočna kartica:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Display help </source>
        <translation type="vanished">Prikaži pomoč</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="vanished">Pomoč</translation>
    </message>
    <message>
        <source>Alt+H</source>
        <translation type="vanished">Alt+H</translation>
    </message>
    <message>
        <source>About this application</source>
        <translation type="vanished">O tem programu</translation>
    </message>
    <message>
        <source>About...</source>
        <translation type="vanished">O programu...</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="vanished">Alt+B</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="vanished">Zapri aplikacijo</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Zapri</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="vanished">Alt+N</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="vanished">Uveljavi</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select another sound card if necessary:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;/p&gt;Če je potrebno izberite drugo zvočno kartico:&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;If your computer has more than one sound card, you can use this application to select the one to be default. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Če ima vaš računalnik več kot eno zvočno kartico, lahko uporabite to aplikacijo, da določite, katera bo privzeta. &lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Test current sound card</source>
        <translation type="vanished">Preizkus trenutne zvočne kartice</translation>
    </message>
    <message>
        <source>No sound cards/devices were found.</source>
        <translation type="vanished">Zvočnih kartic ali naprav ni bilo mogoče najti</translation>
    </message>
    <message>
        <source>none</source>
        <translation type="vanished">brez</translation>
    </message>
    <message>
        <source>About MX Select Sound</source>
        <translation type="vanished">O programu MX Izbira zvoka</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">Različica:</translation>
    </message>
    <message>
        <source>Program for selecting the default sound card in MX Linux</source>
        <translation type="vanished">Program za določitev privzete zvočne kartice v MX Linuxu</translation>
    </message>
    <message>
        <source>Copyright (c) MX Linux</source>
        <translation type="vanished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licenca</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Dnevnik sprememb</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Prekliči</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Zapri</translation>
    </message>
    <message>
        <source>Could not play test sound.</source>
        <translation type="vanished">Preizkusnega zvoka ni bilo mogoče predvajati.</translation>
    </message>
</context>
</TS>
